@@ -7,6 +7,8 @@
 */
 
 #include "incidencedialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "combinedincidenceeditor.h"
 #include "editorconfig.h"
 #include "incidencealarm.h"
@@ -24,8 +26,6 @@
 #include "templatemanagementdialog.h"
 #include "ui_dialogdesktop.h"
 
-#include "incidenceeditorsettings.h"
-
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
@@ -53,7 +53,7 @@
 using namespace IncidenceEditorNG;
 namespace
 {
-static const char myIncidenceDialogConfigGroupName[] = "IncidenceDialog";
+const char myIncidenceDialogConfigGroupName[] = "IncidenceDialog";
 
 IncidenceEditorNG::EditorItemManager::ItipPrivacyFlags toItemManagerFlags(bool sign, bool encrypt)
 {
@@ -94,7 +94,6 @@ public:
     Akonadi::Item mItem;
     [[nodiscard]] QString typeToString(const int type) const;
 
-public:
     IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer, IncidenceDialog *qq);
     ~IncidenceDialogPrivate() override;
 
@@ -104,7 +103,7 @@ public:
     void loadTemplate(const QString &templateName);
     void manageTemplates();
     void saveTemplate(const QString &templateName);
-    void storeTemplatesInConfig(const QStringList &newTemplates);
+    void storeTemplatesInConfig(const QStringList &templateNames);
     void updateAttachmentCount(int newCount);
     void updateAttendeeCount(int newCount);
     void updateResourceCount(int newCount);
@@ -125,6 +124,11 @@ public:
     [[nodiscard]] Akonadi::Collection selectedCollection() const override;
 
     void reject(RejectReason reason, const QString &errorMessage = QString()) override;
+
+private:
+    // disable copy ctor
+    IncidenceDialogPrivate(const IncidenceDialogPrivate &) = delete;
+    IncidenceDialogPrivate &operator=(const IncidenceDialogPrivate &) = delete;
 };
 }
 
@@ -295,13 +299,13 @@ QString IncidenceDialogPrivate::typeToString(const int type) const
     // Do not translate.
     switch (type) {
     case KCalendarCore::Incidence::TypeEvent:
-        return QStringLiteral("Event");
+        return u"Event"_s;
     case KCalendarCore::Incidence::TypeTodo:
-        return QStringLiteral("Todo");
+        return u"Todo"_s;
     case KCalendarCore::Incidence::TypeJournal:
-        return QStringLiteral("Journal");
+        return u"Journal"_s;
     default:
-        return QStringLiteral("Unknown");
+        return u"Unknown"_s;
     }
 }
 
@@ -309,10 +313,10 @@ void IncidenceDialogPrivate::loadTemplate(const QString &templateName)
 {
     Q_Q(IncidenceDialog);
 
-    KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+    KCalendarCore::MemoryCalendar::Ptr const cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
 
-    const QString fileName = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                                    QStringLiteral("/korganizer/templates/") + typeToString(mEditor->type()) + QLatin1Char('/') + templateName);
+    const QString fileName =
+        QStandardPaths::locate(QStandardPaths::GenericDataLocation, u"/korganizer/templates/"_s + typeToString(mEditor->type()) + u'/' + templateName);
 
     if (fileName.isEmpty()) {
         KMessageBox::error(q, i18nc("@info", "Unable to find template '%1'.", templateName));
@@ -332,11 +336,11 @@ void IncidenceDialogPrivate::loadTemplate(const QString &templateName)
     }
 
     mIeDateTime->setActiveDate(QDate());
-    KCalendarCore::Incidence::Ptr newInc = KCalendarCore::Incidence::Ptr(incidences.first()->clone());
+    KCalendarCore::Incidence::Ptr const newInc = KCalendarCore::Incidence::Ptr(incidences.first()->clone());
     newInc->setUid(KCalendarCore::CalFormat::createUniqueId());
 
     // We add a custom property so that some fields aren't loaded, dates for example
-    newInc->setCustomProperty(QByteArray("kdepim"), "isTemplate", QStringLiteral("true"));
+    newInc->setCustomProperty(QByteArray("kdepim"), "isTemplate", u"true"_s);
     mEditor->load(newInc);
     newInc->removeCustomProperty(QByteArray(), "isTemplate");
 }
@@ -345,9 +349,9 @@ void IncidenceDialogPrivate::manageTemplates()
 {
     Q_Q(IncidenceDialog);
 
-    QStringList &templates = IncidenceEditorNG::EditorConfig::instance()->templates(mEditor->type());
+    const QStringList &templates = IncidenceEditorNG::EditorConfig::instance()->templates(mEditor->type());
 
-    QPointer<IncidenceEditorNG::TemplateManagementDialog> dialog(
+    QPointer<IncidenceEditorNG::TemplateManagementDialog> const dialog(
         new IncidenceEditorNG::TemplateManagementDialog(q, templates, KCalUtils::Stringify::incidenceType(mEditor->type())));
 
     q->connect(dialog, &TemplateManagementDialog::loadTemplate, q, [this](const QString &templateName) {
@@ -367,23 +371,23 @@ void IncidenceDialogPrivate::saveTemplate(const QString &templateName)
 {
     Q_ASSERT(!templateName.isEmpty());
 
-    KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+    KCalendarCore::MemoryCalendar::Ptr const cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
 
     switch (mEditor->type()) {
     case KCalendarCore::Incidence::TypeEvent: {
-        KCalendarCore::Event::Ptr event(new KCalendarCore::Event());
+        KCalendarCore::Event::Ptr const event(new KCalendarCore::Event());
         mEditor->save(event);
         cal->addEvent(KCalendarCore::Event::Ptr(event->clone()));
         break;
     }
     case KCalendarCore::Incidence::TypeTodo: {
-        KCalendarCore::Todo::Ptr todo(new KCalendarCore::Todo);
+        KCalendarCore::Todo::Ptr const todo(new KCalendarCore::Todo);
         mEditor->save(todo);
         cal->addTodo(KCalendarCore::Todo::Ptr(todo->clone()));
         break;
     }
     case KCalendarCore::Incidence::TypeJournal: {
-        KCalendarCore::Journal::Ptr journal(new KCalendarCore::Journal);
+        KCalendarCore::Journal::Ptr const journal(new KCalendarCore::Journal);
         mEditor->save(journal);
         cal->addJournal(KCalendarCore::Journal::Ptr(journal->clone()));
         break;
@@ -392,8 +396,8 @@ void IncidenceDialogPrivate::saveTemplate(const QString &templateName)
         Q_ASSERT_X(false, "saveTemplate", "Fix your program");
     }
 
-    QString fileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/korganizer/templates/")
-        + typeToString(mEditor->type()) + QLatin1Char('/');
+    QString fileName =
+        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + u"/korganizer/templates/"_s + typeToString(mEditor->type()) + u'/';
     QDir().mkpath(fileName);
     fileName += templateName;
 
@@ -406,8 +410,8 @@ void IncidenceDialogPrivate::storeTemplatesInConfig(const QStringList &templateN
     // I find this somewhat broken. templates() returns a reference, maybe it should
     // be changed by adding a setTemplates method.
     const QStringList origTemplates = IncidenceEditorNG::EditorConfig::instance()->templates(mEditor->type());
-    const QString defaultPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("korganizer/templates/")
-        + typeToString(mEditor->type()) + QLatin1Char('/');
+    const QString defaultPath =
+        QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + u"korganizer/templates/"_s + typeToString(mEditor->type()) + u'/';
     QDir().mkpath(defaultPath);
     for (const QString &tmpl : origTemplates) {
         if (!templateNames.contains(tmpl)) {
@@ -471,11 +475,8 @@ void IncidenceDialogPrivate::handleItemSaveFail(EditorItemManager::SaveAction, c
                                       "Unable to store the incidence in the calendar. Try again?\n\n "
                                       "Reason: %1",
                                       errorMessage);
-        const int answer = KMessageBox::warningTwoActions(q,
-                                                          message,
-                                                          QString(),
-                                                          KGuiItem(i18nc("@action:button", "Retry"), QStringLiteral("dialog-ok")),
-                                                          KStandardGuiItem::cancel());
+        const int answer =
+            KMessageBox::warningTwoActions(q, message, QString(), KGuiItem(i18nc("@action:button", "Retry"), u"dialog-ok"_s), KStandardGuiItem::cancel());
         retry = (answer == KMessageBox::ButtonCode::PrimaryAction);
     }
 
@@ -505,9 +506,9 @@ void IncidenceDialogPrivate::handleItemSaveFinish(EditorItemManager::SaveAction
         const int answer = KMessageBox::questionTwoActions(q,
                                                            message,
                                                            i18nc("@title:window", "Set Default Calendar?"),
-                                                           KGuiItem(i18nc("@action:button", "Set As Default"), QStringLiteral("dialog-ok")),
-                                                           KGuiItem(i18nc("@action:button", "Do Not Set"), QStringLiteral("dialog-cancel")),
-                                                           QStringLiteral("setDefaultCalendarCollection"));
+                                                           KGuiItem(i18nc("@action:button", "Set As Default"), u"dialog-ok"_s),
+                                                           KGuiItem(i18nc("@action:button", "Do Not Set"), u"dialog-cancel"_s),
+                                                           u"setDefaultCalendarCollection"_s);
         if (answer == KMessageBox::ButtonCode::PrimaryAction) {
             CalendarSupport::KCalPrefs::instance()->setDefaultCalendarId(mItem.storageCollectionId());
         }
@@ -610,11 +611,11 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
     }
 
     if (mEditor->type() == KCalendarCore::Incidence::TypeTodo) {
-        q->setWindowIcon(QIcon::fromTheme(QStringLiteral("view-calendar-tasks")));
+        q->setWindowIcon(QIcon::fromTheme(u"view-calendar-tasks"_s));
     } else if (mEditor->type() == KCalendarCore::Incidence::TypeEvent) {
-        q->setWindowIcon(QIcon::fromTheme(QStringLiteral("view-calendar-day")));
+        q->setWindowIcon(QIcon::fromTheme(u"view-calendar-day"_s));
     } else if (mEditor->type() == KCalendarCore::Incidence::TypeJournal) {
-        q->setWindowIcon(QIcon::fromTheme(QStringLiteral("view-pim-journal")));
+        q->setWindowIcon(QIcon::fromTheme(u"view-pim-journal"_s));
     }
 
     // Initialize tab's titles
@@ -633,8 +634,8 @@ Akonadi::Item IncidenceDialogPrivate::save(const Akonadi::Item &item)
 {
     Q_ASSERT(mEditor->incidence<KCalendarCore::Incidence>());
 
-    KCalendarCore::Incidence::Ptr incidenceInEditor = mEditor->incidence<KCalendarCore::Incidence>();
-    KCalendarCore::Incidence::Ptr newIncidence(incidenceInEditor->clone());
+    KCalendarCore::Incidence::Ptr const incidenceInEditor = mEditor->incidence<KCalendarCore::Incidence>();
+    KCalendarCore::Incidence::Ptr const newIncidence(incidenceInEditor->clone());
 
     Akonadi::Item result = item;
     result.setMimeType(newIncidence->mimeType());
@@ -693,7 +694,7 @@ IncidenceDialog::IncidenceDialog(Akonadi::IncidenceChanger *changer, QWidget *pa
 
     auto defaultButton = d->mUi->buttonBox->button(QDialogButtonBox::RestoreDefaults);
     defaultButton->setText(i18nc("@action:button", "&Templates…"));
-    defaultButton->setIcon(QIcon::fromTheme(QStringLiteral("project-development-new-template")));
+    defaultButton->setIcon(QIcon::fromTheme(u"project-development-new-template"_s));
     defaultButton->setToolTip(i18nc("@info:tooltip", "Manage templates for this item"));
     defaultButton->setWhatsThis(i18nc("@info:whatsthis",
                                       "Push this button to show a dialog that helps "
@@ -731,7 +732,7 @@ void IncidenceDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(500, 500));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myIncidenceDialogConfigGroupName));
+    KConfigGroup const group(KSharedConfig::openStateConfig(), QLatin1StringView(myIncidenceDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
@@ -771,6 +772,7 @@ void IncidenceDialog::slotButtonClicked(QAbstractButton *button)
 {
     Q_D(IncidenceDialog);
 
+    // NOLINTBEGIN(bugprone-branch-clone)
     if (d->mUi->buttonBox->button(QDialogButtonBox::Ok) == button) {
         if (d->isDirty() || d->mInitiallyDirty) {
             d->mUi->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(false);
@@ -795,8 +797,8 @@ void IncidenceDialog::slotButtonClicked(QAbstractButton *button)
             && KMessageBox::questionTwoActions(this,
                                                i18nc("@info", "Do you really want to cancel?"),
                                                i18nc("@title:window", "KOrganizer Confirmation"),
-                                               KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
-                                               KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")))
+                                               KGuiItem(i18nc("@action:button", "Cancel Editing"), u"dialog-ok"_s),
+                                               KGuiItem(i18nc("@action:button", "Do Not Cancel"), u"dialog-cancel"_s))
                 == KMessageBox::ButtonCode::PrimaryAction) {
             QDialog::reject(); // Discard current changes
         } else if (!d->isDirty()) {
@@ -807,33 +809,41 @@ void IncidenceDialog::slotButtonClicked(QAbstractButton *button)
     } else {
         Q_ASSERT(false); // Shouldn't happen
     }
+    // NOLINTEND(bugprone-branch-clone)
 }
 
 void IncidenceDialog::reject()
 {
+    /* cppcheck-suppress constVariablePointer */
     Q_D(IncidenceDialog);
+
+    // NOLINTBEGIN(bugprone-branch-clone)
     if (d->isDirty()
         && KMessageBox::questionTwoActions(this,
                                            i18nc("@info", "Do you really want to cancel?"),
                                            i18nc("@title:window", "KOrganizer Confirmation"),
-                                           KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
-                                           KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")))
+                                           KGuiItem(i18nc("@action:button", "Cancel Editing"), u"dialog-ok"_s),
+                                           KGuiItem(i18nc("@action:button", "Do Not Cancel"), u"dialog-cancel"_s))
             == KMessageBox::ButtonCode::PrimaryAction) {
         QDialog::reject(); // Discard current changes
     } else if (!d->isDirty()) {
         QDialog::reject(); // No pending changes, just close the dialog.
     }
+    // NOLINTEND(bugprone-branch-clone)
 }
 
 void IncidenceDialog::closeEvent(QCloseEvent *event)
 {
+    /* cppcheck-suppress constVariablePointer */
     Q_D(IncidenceDialog);
+
+    // NOLINTBEGIN(bugprone-branch-clone)
     if (d->isDirty()
         && KMessageBox::questionTwoActions(this,
                                            i18nc("@info", "Do you really want to cancel?"),
                                            i18nc("@title:window", "KOrganizer Confirmation"),
-                                           KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
-                                           KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")))
+                                           KGuiItem(i18nc("@action:button", "Cancel Editing"), u"dialog-ok"_s),
+                                           KGuiItem(i18nc("@action:button", "Do Not Cancel"), u"dialog-cancel"_s))
             == KMessageBox::ButtonCode::PrimaryAction) {
         QDialog::reject(); // Discard current changes
         QDialog::closeEvent(event);
@@ -843,6 +853,7 @@ void IncidenceDialog::closeEvent(QCloseEvent *event)
     } else {
         event->ignore();
     }
+    // NOLINTEND(bugprone-branch-clone)
 }
 
 void IncidenceDialog::setInitiallyDirty(bool initiallyDirty)
